@@ -33,10 +33,12 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         event_type = self.get_event_type()
         event = self.clean_event(event)
 
+        max_lookback_seconds = self.get_max_lookback_seconds()
+        event = self.format_event(event_type, event)
         self.asset_id = self.determine_asset_id(event)
+
         self.state = self.load_state()
 
-        max_lookback_seconds = self.get_max_lookback_seconds()
         self.event = self.load_event(event_type, event, max_lookback_seconds)
         self.log_event(self.event, max_lookback_seconds)
 
@@ -114,9 +116,8 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         :return: list of WITS data between the last processed timestamp and the final event item timestamp
         """
 
-        event = self.format_scheduler_event(event)
-        start_timestamp = self.state.get('last_processed_timestamp', event[0].get('timestamp'))
-        end_timestamp = event[-1].get('timestamp', start_timestamp)
+        start_timestamp = self.state.get('last_processed_timestamp', event[0].get('timestamp') - 1)
+        end_timestamp = event[-1].get('timestamp')
 
         # the event is converted from scheduler to wits stream
         scheduler_event = gather_wits_for_period(
@@ -128,41 +129,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         return scheduler_event
 
     @staticmethod
-    def format_scheduler_event(event: list) -> list:
-        """
-        validate the scheduler event, flatten and organize the data into a desired format
-        :param event: a scheduler event
-        :return: a dict structured in such a way that the key is asset_id and
-        the value is the wits records that belong to that asset_id
-        """
-
-        flat_events = []
-
-        try:
-            # Because the events are structured into 'list of lists', using the following code
-            # converts them into a flat single list. This is done for better data processing in
-            # the proceeding steps.
-            flat_events = [item for sublist in event for item in sublist]
-        except ValueError:
-            raise Exception("Records are not valid JSON: {0}...".format(str(flat_events)[:100]))
-
-        if not isinstance(flat_events, list):
-            raise Exception("Records is not an array: {0}".format(flat_events))
-
-        if not flat_events:
-            raise Exception("Records is empty.")
-
-        events = [
-            {
-                "asset_id": item["asset_id"],
-                "timestamp": int(item['schedule_start'] / 1000)
-            }
-            for item in flat_events
-        ]
-
-        return events
-
-    def load_wits_stream_event(self, asset_id, event, max_lookback_seconds):
+    def load_wits_stream_event(asset_id, event, max_lookback_seconds):
         """
         To load a wits stream event and get more data if necessary
         :param asset_id: The asset to load
@@ -172,7 +139,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         """
 
         if event and max_lookback_seconds:
-            first_timestamp = self.event[0].get('timestamp')
+            first_timestamp = event[0].get('timestamp')
 
             if not first_timestamp:
                 return event
@@ -190,10 +157,56 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
 
         return event
 
+    @staticmethod
+    def format_event(event_type: str, event: list) -> list:
+        """
+        validate the wits_stream event, flatten and organize the data into a desired format
+        :param event_type: type of event
+        :param event: a wits_stream event
+        :return: a list of wits records
+        """
+
+        first_event = event[0]
+        if isinstance(first_event, list):
+            # This is possible for both scheduler and old wits stream event types
+            try:
+                # Because the events are structured into 'list of lists', using the following code
+                # converts them into a flat single list. This is done for better data processing in
+                # the proceeding steps.
+                event = [item for sublist in event for item in sublist]
+            except ValueError:
+                raise Exception("Records are not valid JSON")
+
+            if not isinstance(event, list):
+                raise Exception("Records is not an array")
+
+            if not event:
+                raise Exception("Records is empty.")
+
+            if event_type == 'scheduler':
+                event = [
+                    {
+                        "asset_id": item["asset_id"],
+                        "timestamp": int(item['schedule_start'] / 1000)
+                    }
+                    for item in event
+                ]
+            return event
+
+        elif isinstance(first_event, dict):
+            # This is possible for the new wits stream event type
+            records = []
+            for each in event:
+                records = records + each.get("records", [])
+            return records
+
+        else:
+            raise TypeError(f"Event is neither a scheduler, old nor new kafka consumer")
+
     @staticmethod
     def determine_asset_id(event: list) -> int:
         try:
-            return int(event[0][0]["asset_id"])
+            return int(event[0]["asset_id"])
         except Exception:
             raise Exception('Event does not contain asset_id: {}'.format(event))
 
