@@ -1,8 +1,8 @@
-from typing import Union
-
+import json
+from typing import Union, Tuple
 import numpy as np
-
 from worker.data.api import API
+from worker.data.enums import EventTypes
 
 
 def gather_wits_for_period(asset_id: int, start: int, end: int, limit: int = 1800) -> list:
@@ -45,12 +45,6 @@ def get_one_wits_record(asset_id: int, timestamp_sort: int = -1) -> dict:
     return data[0]
 
 
-def get_config_by_id(config_collection: str, _id: str):
-    worker = API()
-    config = worker.get(path="/v1/data/corva/%s/%s" % (config_collection, _id)).data
-    return config
-
-
 def delete_collection_data_of_asset_id(asset_id: int, collections: Union[str, list]):
     """
     Delete all the data of a collection for an asset id.
@@ -100,6 +94,19 @@ def is_finite(data):
         return False
 
 
+def is_int(s: str) -> bool:
+    """
+    To check if the given string is an integer or not
+    :param s:
+    :return:
+    """
+    try:
+        int(s)
+        return True
+    except ValueError:
+        return False
+
+
 def to_number(data):
     """
     Check and return if the data can be cast to a number, else return None
@@ -128,41 +135,38 @@ def none_to_nan(data):
     return data
 
 
-def get_value_from_dict(data: dict, key: str, func=lambda x: x, default=None):
+def get_data_by_path(data: dict, path: str, func=lambda x: x, default=None):
     """
-    An structured way of getting data from a dict.
-    :param data:
-    :param key:
-    :param func: the type of the data (int, str, float, ...)
-    :param default:
-    :return:
-    """
-    value = data.get(key, None)
-    if value is not None:
-        try:
-            return_value = func(value)
-            return return_value
-        except ValueError:
-            pass
-
-    return default
-
-
-def get_dict_data_by_path(data: dict, key_path: str, default=None):
-    """
-    To find the path to a key in data dictionary.
+    To find the path to a key in a nested dictionary.
     Note that none of the keys should end up in a list
     :param data:
-    :param key_path: path to the final key, e.g. 'data.X.Y'
-    :param default:
+    :param path: path to the final key; example of the paths are:
+        'data.X.Y'
+        'data.bit_depth'
+    :param func: the type of the data (int, str, float, ...)
+    :param default: default value if the path not found
     :return:
     """
-    keys = key_path.split('.')
-    for key in keys:
-        data = data.get(key, {})
-    if not data:
-        return default
-    return data
+    if not path:
+        if default is not None:
+            return default
+
+        raise KeyError("No key provided")
+
+    keys = path.split('.')
+
+    while keys:
+        current_key = keys.pop(0)
+
+        if current_key not in data:
+            if default:
+                return default
+
+            raise KeyError("{0} not found in path".format(current_key))
+
+        data = data.get(current_key)
+
+    return func(data)
 
 
 def is_in_and_not_none(d: dict, key: str):
@@ -201,3 +205,49 @@ def merge_dicts(d1: dict, d2: dict) -> dict:
     """
     d = {**d1, **d2}
     return d
+
+
+def get_cleaned_event_and_type(event) -> Tuple[Union[list, dict], EventTypes]:
+    """
+    validate and flatten the events and organize the data into a desired format
+
+    Task and generic events format is : dict => {}
+    Scheduler events format is: list of list of dict => [[{}]]
+    Kafka events format is: list of dict => [{}]
+    The above formats can be used to determine the format
+
+    :param event: a scheduler of kafka stream
+    :return: event and event_type
+    """
+
+    if not event:
+        raise ValueError("Empty events")
+
+    if isinstance(event, (str, bytes, bytearray)):
+        event = json.loads(event)
+
+    if isinstance(event, dict):
+        if "asset_id" in event:
+            return event, EventTypes.GENERIC
+
+        if "task_id" in event:
+            return event, EventTypes.TASK
+
+        raise TypeError(f"Missing task_id or asset_id keys in event")
+
+    if not isinstance(event, list):
+        raise TypeError(f"Event is not a list or a dict")
+
+    first_event = event[0]
+    if isinstance(first_event, list):
+        if first_event[0] and "schedule_start" in first_event[0]:
+            return event, EventTypes.SCHEDULER
+
+        raise Exception(f"Missing scheduler_start key in scheduler event")
+
+    elif isinstance(first_event, dict):
+        # new kafka stream format: list of json objects, each with metadata and records
+        # event = [{"metadata": { ... }, "records": [ ... ]}, {"metadata": { ... }, "records": [ ... ]}]
+        return event, EventTypes.STREAM
+
+    raise TypeError(f"Event is not either a scheduler or kafka consumer")
