@@ -26,7 +26,7 @@ from distutils.util import strtobool
 from tqdm import tqdm
 
 from worker import constants
-from worker.data.operations import delete_collection_data_of_asset_id, get_one_wits_record
+from worker.data.operations import delete_collection_data_of_asset_id, get_one_wits_record, gather_wits_for_period
 from worker.framework.mixins import RedisMixin
 from worker.test.utils import get_last_processed_timestamp, create_scheduler_events
 
@@ -41,6 +41,7 @@ def generate_parser():
     parser.add_argument("-s", "--start_timestamp", "--start", type=int, required=False, default=None, help="start timestamp")
     parser.add_argument("-e", "--end_timestamp", "--end", type=int, required=False, default=None, help="end timestamp")
     parser.add_argument("-i", "--timestep", "--step", type=int, required=False, default=60, help="trigger the lambda function once every step")
+    parser.add_argument("-t", "--event_type", "--event", type=str, required=False, default="scheduler", help="type of event, scheduler or wits_stream")
     parser.add_argument("-d", "--to_delete", "--delete", type=strtobool, required=False, default=False, help="to delete the state and data")
     return parser
 
@@ -50,6 +51,7 @@ class AppTestRun:
         self.lambda_handler = lambda_handler
         self.collections = collections
 
+        self.event_type = None
         self.progress = None
 
         if args is None:
@@ -63,6 +65,7 @@ class AppTestRun:
         start_timestamp = args.start_timestamp
         end_timestamp = args.end_timestamp
         step = args.timestep
+        self.event_type = args.event_type
         to_delete = args.to_delete
 
         app_redis = "corva/{0}.{1}".format(asset_id, constants.get("global.app-key"))
@@ -85,5 +88,15 @@ class AppTestRun:
 
     def run(self):
         for e in self.progress:
+            schedule_time = str(int(e[0][0]['schedule_start'] / 1000))
+            if self.event_type == "wits_stream":
+                wits = gather_wits_for_period(
+                    int(e[0][0]['asset_id']),
+                    int(e[0][0]['schedule_start'] / 1000),
+                    int(e[0][0]['schedule_end'] / 1000)
+                )
+                if not wits:
+                    continue
+                e = [wits]
             self.lambda_handler(e, None)
-            self.progress.set_description(str(int(e[0][0]['schedule_start'] / 1000)))
+            self.progress.set_description(schedule_time)
